#!/bin/bash
source "$AGENT_PATH/_common.sh"

# START SCRIPT
# The start script is required for all templates.
# It is used to start the service on the server.

check_required_env_vars "CONTAINER_NAME" "DATA_VOLUME" "CONFIG_VOLUME"


DOCKER_RUN_CMD="docker run -d \
                --restart unless-stopped \
                --name ${CONTAINER_NAME} \
                -p 80:80 \
                -p 443:443 \
                -p 443:443/udp \
                -v ${CONFIG_PATH}/Caddyfile:/etc/caddy/Caddyfile \
                -v ${DATA_VOLUME}:/data \
                -v ${CONFIG_VOLUME}:/config \
                -v ${CONFIG_PATH}/static:/srv \
                ${IMAGE_REGISTRY}/${IMAGE_REPO}:${IMAGE_TAG}"


if ! create_and_start_container "$DOCKER_RUN_CMD" "$CONTAINER_NAME"; then
    die "Failed to start container ${CONTAINER_NAME}"
fi

# Check if the container is running
if ! _is_container_running "$CONTAINER_NAME"; then
    die "Container ${CONTAINER_NAME} is not running"
fi

echo "Container ${CONTAINER_NAME} started"
