#!/bin/bash
source "$(dirname "$0")/_common.sh"

check_required_env_vars \
    "IMAGE_REGISTRY" \
    "IMAGE_REPO" \
    "IMAGE_TAG" \
    "CONTAINER_NAME" \
    "LOCAL_DATA_FOLDER"


# Create local data folder if it doesn't exist
if [ -d "${LOCAL_DATA_FOLDER}" ]; then
    echo "Local data folder ${LOCAL_DATA_FOLDER} exists, using existing data."
else
    echo "Local data folder ${LOCAL_DATA_FOLDER} does not exist, creating..."
    mkdir -p "${LOCAL_DATA_FOLDER}"
fi


# Test Docker 
_check_docker_installed || die "Docker test failed, aborting installation..."

# Create deploy and data folders
[ -z "$LOCAL_DATA_FOLDER" ] && die "LOCAL_DATA_FOLDER is not set"
create_folder "$LOCAL_DATA_FOLDER"

# check can pull image on remote host and exit if fails
docker pull "$IMAGE_REGISTRY/$IMAGE_REPO:$IMAGE_TAG" || die "Failed to pull image $IMAGE_REGISTRY/$IMAGE_REPO:$IMAGE_TAG"

# remove and restart, as the env may have changed.
bash ./stop.sh || die "Failed to stop container ${CONTAINER_NAME}"
_remove_container $CONTAINER_NAME || die "Failed to remove container ${CONTAINER_NAME}"
bash ./start.sh || die "Failed to start container ${CONTAINER_NAME}"

echo "Installation of ${CONTAINER_NAME} complete"
